/**
 * aas.LogViewer、aas.RealtimeLogViewer和QueriedLogViewer对象
 */
;
(function($, aas, _) {
    var LogViewer = null;

    LogViewer = aas.LogViewer = aas.Core.extend({
        /** 显示日志的容器HTML元素选择器 */
        container : undefined,

        /** 每次获取日志的最大数量，不设置或者设置数字小于0则不限制 */
        maxCount : 200,

        /** 当前行日志的级别 */
        currentLogLevel : undefined,

        /** 上一行日志的级别 */
        lastLogLevel : undefined,

        /** 当前显示的日志类别，undefined表示全部显示 */
        currentCategory : undefined,

        /** 日志计数器，用于统计日志的数量 */
        counter : {
            debug : 0,
            info : 0,
            warn : 0,
            error : 0
        },

        counterContainer : null,

        _options : null,

        autoScroll : true,
        
        /** 当前显示的日志级别 */
        currentShowLevel : undefined,

        initialize : function(cfg) {
            var options = this._options = cfg;
            var container = this.container = $(options.container);
            this.counterContainer = $(options.counterContainer);
            this.maxCount = options.maxCount;
            this.lastLogLevel = LogViewer.LogLevel.error;
            this.currentLogLevel = LogViewer.LogLevel.error;
            container.addClass('log_container');
            container.height(container.parent().height()).width(container.parent().width());
        },

        /**
         * 打印日志：
         * 
         * data : 要打印的日志，可以是一个字符串数组，也可以是一个字符串 before : 是否在最前面打印，默认为false
         * callback : 打印单行之后的回调函数，包含两个参数，第一个是打印的日志行数据，第二个参数为日志的级别。不传则不执行
         * 
         */
        printLog : function(data, before, callback) {
            if (data == undefined || !data instanceof Array || data.length == 0) {
                return;
            }
            for ( var i in data) {
                var level = LogViewer.getLogLevel(data[i]);
                if (level != undefined) {
                    this.counter[level.name]++;
                } else {
                    level = this.lastLogLevel;                    
                }
                this.lastLogLevel = level;
                this.currentLogLevel = level;
                var dom = $(LogViewer.buildLogDOM(data[i], level));
                if(this.currentShowLevel != undefined && level != this.currentShowLevel) {
                    dom.css('display', 'none');
                }
                if (before) {
                    this.container.prepend(dom);
                } else {
                    this.container.append(dom);
                    if (this.autoScroll) {
                        this.container[0].scrollTop = this.container[0].scrollHeight;
                    }
                }
                if (callback && callback instanceof Function) {
                    callback.call(data[i], level);
                }
            }
            this.refreshCounter();
        },
        
        showLog : function(level) {
            this.currentShowLevel = level;
            if(level == undefined) {
                this.container.find('.log_msg').css('display', 'block');
            } else {
                for(var k in LogViewer.LogLevel) {
                    if(LogViewer.LogLevel[k] == level) {
                        this.container.find('.' + LogViewer.LogLevel[k].cls).css('display', 'block');
                    } else {
                        this.container.find('.' + LogViewer.LogLevel[k].cls).css('display', 'none');
                    }
                }
            }
        },

        refreshCounter : function() {
            var ct = this.counter;
            this.counterContainer.find('.all .count').text(ct.debug + ct.info + ct.warn + ct.error);
            this.counterContainer.find('.info .count').text(ct.info);
            this.counterContainer.find('.warn .count').text(ct.warn);
            this.counterContainer.find('.error .count').text(ct.error);
        },

        clearLog : function() {
            this.container.find('.log_msg').remove();
            for (k in this.counter) {
                this.counter[k] = 0;
            }
            this.refreshCounter();
        }
    }, {
        /** 单条日志的正则表达式前缀 */
        LOG_PREFIX_REG_EXP : /^[0-9]{4}-[0-9]{2}-[0-9]{2}/,

        /** 每一行日志的DOM模板 */
        LOG_DOM_TPL : '<div class="log_msg {0}"><pre>{1}</pre></div>',

        /** 日志级别 */
        LogLevel : {
            debug : {
                name : 'debug',
                /** 日志的显示样式 */
                cls : 'log_debug',
                /** 日志校验正则表达式 */
                regExp : / 调试 |DEBUG/i
            },
            info : {
                name : 'info',
                cls : 'log_info',
                regExp : / 信息 |INFO/i
            },
            warn : {
                name : 'warn',
                cls : 'log_warn',
                regExp : / 注意 | 警告 |WARN/i
            },
            error : {
                name : 'error',
                cls : 'log_error',
                regExp : / 错误 | 严重 |ERROR|FATAL|Exception/i
            }
        },

        /** 获取单行日志的级别 */
        getLogLevel : function(msg) {
            if (this.LOG_PREFIX_REG_EXP.test(msg)) {
                for (k in this.LogLevel) {
                    if (this.LogLevel[k].regExp.test(msg)) {
                        return this.LogLevel[k];
                    }
                }
            }
        },

        /**
         * 构造单行日志DOM字符串
         * 
         */
        buildLogDOM : function(msg, level) {
            return this.LOG_DOM_TPL.format(level.cls, msg);
        }
    });

    /**
     * 实时日志对象，用于实时日志的显示
     */
    var RealTimeLogViewer = null;
    RealTimeLogViewer = aas.RealTimeLogViewer = aas.LogViewer.extend({

        /** 监控计时的HTML元素 */
        timmerContainer : undefined,

        /** 获取日志数据URL */
        dataURL : undefined,

        fetchLogTimmer : null,

        refreshTimeTimmer : null,

        /** 记录监控时长 */
        time : [ 0, 0, 0 ],

        initialize : function(cfg) {
            RealTimeLogViewer.__super__.initialize.apply(this, [ cfg ]);
            this.timmerContainer = $(cfg.timmerContainer);
            this.dataURL = cfg.dataURL;
            this.startURL = cfg.startURL;
            this.stopURL = cfg.stopURL;
        },

        startMonitor : function(clear) {
            if (clear) {
                this.clearLog();
            }
            this.fetchLogTimmer = setInterval(this.fetchLog.createDelegate(this), 1000);
            this.monitorTimeTimmer = setInterval(this.refreshTime.createDelegate(this), 1000);
        },

        setAutoScroll : function(autoScroll) {
            this.autoScroll = autoScroll;
        },

        refreshTime : function() {
            this.time[2]++;
            if (this.time[2] == 60) {
                this.time[2] = 0;
                this.time[1]++;
            }
            if(this.time[1] == 60) {
                this.time[1] = 0;
                this.time[0]++;
            }
            this.timmerContainer.text('监控时长：{0}小时{1}分{2}秒'.format(this.time[0], this.time[1], this.time[2]));
        },

        /**
         * 停止实施日志监控
         */
        stopMonitor : function() {
            clearInterval(this.fetchLogTimmer);
            clearInterval(this.monitorTimeTimmer);
        },
        
        clearLog : function() {
            RealTimeLogViewer.__super__.clearLog.apply(this);
            this.time = [0, 0, 0];
            this.timmerContainer.text('监控时长：--小时--分--秒');
        },

        /**
         * 获取实时日志并显示
         */
        fetchLog : function() {
            var _t = this;
            $.ajax({
                url : _t.dataURL,
                dataType : 'json',
                data : {
                    maxCount : _t.maxCount
                },
                success : function(data) {
                    if (data && data instanceof Array) {
                        _t.printLog(data, false);
                    } else {
                        aas.utils.error(data.content);
                        _t.stopMonitor();
                    }
                }
            });
        }
    });
    
    var QueriedLogViewer = null;
    QueriedLogViewer = aas.QueriedLogViewer = aas.LogViewer.extend({
        dataURL : null,
        
        boundaryStart : null,
        boundaryEnd : null,
        displayStart : null,
        displayEnd : null,
        queryWord : null,
        
        autoScroll : false,
        
        _hasMoreData : true,
        
        _isFetching : false,
        
        initialize : function(cfg) {
            QueriedLogViewer.__super__.initialize.apply(this, [ cfg ]);
            this.dataURL = cfg.dataURL;
        },
        
        queryLog : function(startTime, endTime, queryWord) {
            this.clearLog();
            this.container.unbind('scroll');
            this.boundaryStart = startTime;
            this.boundaryEnd = endTime,
            this.queryWord = queryWord,
            this.displayStart = null,
            this.displayEnd = null,
            this._isFetching = false;

            this.fetchLogs();
            var _t = this;
            this.container.scroll(function() {
                var scrollHight = _t.container[0].scrollHeight;
                var scrollTop = _t.container[0].scrollTop;
                var height = _t.container.height();
                // 当滚动条距离底部100像素的时候加载后续数据
                if(scrollTop + height >= scrollHight - 100 && _t._hasMoreData) {
                    _t.fetchLogs();
                }
            });
        },
        
        fetchLogs : function() {
            if(this._isFetching) {
                return;
            }
            this._isFetching = true;
            var _t = this;
            $.ajax({
                url : _t.dataURL,
                dataType : 'json',
                data : {
                    boundaryStart : _t.boundaryStart,
                    boundaryEnd : _t.boundaryEnd,
                    displayStart : _t.displayStart,
                    displayEnd : _t.displayEnd,
                    queryWord : _t.queryWord
                },
                success : function(data) {
                    _t._isFetching = false;
                    _t.displayStart = data.displayStart;
                    _t.displayEnd = data.displayEnd;
                    _t._hasMoreData = data.hasMore;
                    if (data.logs.length > 0) {
                        _t.printLog(data.logs);
                    }
                }
            });
        }
    });
})(jQuery, aas, _);