;
/**
 * 服务器端文件选择器
 * */
(function($, aas) {
    var SFS = null;
    SFS = aas.utils.ServerFileSelector = aas.Core.extend({
        /**
         * 点击选择按钮后的回调方法，签名为：function(value)，其中参数value为选中的文件的路径
         * */
        callback : null,
        
        /**
         * 是否允许选择目录
         * 
         * TODO 暂未实现
         * */
        allowFolder : true,
        
        /**
         * 可选的文件后缀名，可以设置多个（;隔开），如：'.jar;.war;.ear'
         * */
        suffix : null,
        
        /**
         * 文件名过滤正则表达式（Java）
         * 
         * TODO 暂未实现
         * */
        nameFilter : null,
        
        initialize : function(cfg) {
            this.callback = cfg.callback;
            this.allowFolder = cfg.allowFolder;
            this.suffix = cfg.suffix;
            var _t = this;
            var dialog_tpl = '<div id="selector_north"><label>当前路径：</label><input id="current_folder_path" type="text" disabled="disabled" /></div>' +
                             '<div id="selector_west"><ul id="forder_tree"></ul></div>' +
                             '<div id="selector_center"><table id="file_grid"></table></div>' +
                             '<div id="selector_south"><label>文件名：</label><input id="selected_file_name" type="text" disabled="disabled" /></div>';
            var dialog = $('<div class="file-selector-dialog" />').appendTo($(document.body));
            dialog.omDialog({
                autoOpen : true,
                height : 450,
                width : 600,
                modal : true,
                title : '选择文件',
                buttons : [ {
                    text : '选择',
                    click : function() {
                        if(_t.selectedData == undefined || _t.selectedData.trim().length == 0) {
                            alert(_t.allowFolder ? '请选择文件或目录！' : '请选择文件！');
                        } else {
                            dialog.omDialog('close');
                            _t.callback(_t.selectedData);
                        }
                    }
                }, {
                    text : '取消',
                    click : function() {
                        dialog.omDialog('close');
                    }
                } ],
                onClose : function() {
                    dialog.omDialog('destroy');
                    dialog.remove();
                }
            });
            dialog.css('padding', '0');
            dialog.append($(dialog_tpl));

            dialog.omBorderLayout({
                panels : [ {
                    id : 'selector_north',
                    region : 'north',
                    header : false,
                    resizable : false,
                    collapsible : false
                }, {
                    id : 'selector_west',
                    region : 'west',
                    header : false,
                    resizable : false,
                    collapsible : false,
                    width : 200
                }, {
                    id : 'selector_center',
                    region : 'center',
                    header : false
                }, {
                    id : 'selector_south',
                    region : 'south',
                    header : false,
                    resizable : false,
                    collapsible : false
                } ],
                spacing : 0
            });
            
            $('#forder_tree').omTree({
                dataSource : _t.getContextPath() + SFS.FOLDER_TREE_DATA_URL,
                onSelect : function(n) {
                    $('#current_folder_path').val(n.path);
                    $('#file_grid').omGrid('setData', _t._buildGridDataURL(n.path));
                },
                onBeforeExpand : function(n){
                	var nodeDom = $("#"+n.nid);
                	if(nodeDom.hasClass("hasChildren")){
                		nodeDom.removeClass("hasChildren");
                		$.ajax({
                            url: _t.getContextPath() + SFS.FOLDER_TREE_DATA_URL,
                            data : {
                                parent : n.path
                            },
                            method: 'GET',
                            dataType: 'json',
                            success: function(data){
                                $("#forder_tree").omTree("insert", data, n);
                            }
                        });
                	}
                	return true;
                },
                onDblClick : function(n) {
                    $("#forder_tree").omTree("expand", n);
                }
            });

            $('#file_grid').omGrid({
                height : 279,
                width : '100%',
                limit : 0,
                showIndex : false,
                singleSelect : true,
                colModel : [ {
                    header : '名称',
                    name : 'name',
                    width : 'autoExpand',
                    align : 'left',
                    renderer : function(colValue, rowData, rowIndex) {
                        if(rowData.folder) {
                            return '<span class="folder">{0}</span>'.format(colValue);
                        } else {
                            return '<span class="file">{0}</span>'.format(colValue);
                        }
                    }
                } ],
                dataSource : _t.getContextPath() + SFS.FILE_GRID_DATA_URL,
                onRowSelect : function(rowIndex, data) {
                	if(_t.allowFolder || !data.folder) {
                		_t.selectedData = data.path;
                        $('#selected_file_name').val(data.name);
                	}
                },
                onRowDblClick : function(rowIndex, data) {
                    if(data.folder) {
                        $('#current_folder_path').val(data.path);
                        $('#file_grid').omGrid('setData', _t._buildGridDataURL(data.path));
                    } else {
                        _t.selectedData = data.path;
                        dialog.omDialog('close');
                        _t.callback(_t.selectedData);
                    }
                }
            });
        },
        
        _buildGridDataURL : function(parent) {
            var url = this.getContextPath() + SFS.FILE_GRID_DATA_URL + '?folder=' + encodeURIComponent(parent);
            if(this.suffix != null) {
                url = url + '&suffix=' + encodeURIComponent(this.suffix);
            }
            return url;
        }
    }, {
        FOLDER_TREE_DATA_URL : '/protect/selector/server_file/folders',
        FILE_GRID_DATA_URL : '/protect/selector/server_file/files'
    });
})(jQuery, aas);